package main

import (
	"git.dragse.it/anthrove/e621-sdk-go/pkg/e621/endpoints"
	"git.dragse.it/anthrove/e621-sdk-go/pkg/e621/model"
	_ "github.com/joho/godotenv/autoload"
	"log"
	"net/http"
	"os"
)

func main() {
	// Define the request context with essential information.
	requestContext := model.RequestContext{
		Client:    http.Client{},
		Host:      "https://e621.net",
		UserAgent: "Go-e621-SDK (@username)",
		Username:  os.Getenv("API_USER"), // Replace with your username
		APIKey:    os.Getenv("API_KEY"),  // Replace with your API key
	}

	// Log: Getting favorites from the API.
	log.Println("Getting favorites API user: ")

	// Define query parameters for retrieving favorites.
	query := map[string]string{
		"limit": "5",
	}

	// Call the GetFavorites function to retrieve favorite posts.
	posts, err := endpoints.GetFavorites(requestContext, query)

	if err != nil {
		log.Println(err)
	} else {
		// Log the URL of the first favorite post.
		log.Println(posts[0].File.URL)
	}
	log.Println("----------")

	// Log: Getting favorites for a specific user.
	log.Println("Getting favorites for user: ")

	// Update the query parameters to include a specific user's ID.
	query = map[string]string{
		"user_id": "25483", // Replace with the desired user's ID
		"limit":   "5",
	}

	// Call the GetFavorites function to retrieve favorite posts for the specified user.
	posts, err = endpoints.GetFavorites(requestContext, query)

	if err != nil {
		log.Println(err)
	} else {
		// Log the URL of the first favorite post.
		log.Println(posts[0].File.URL)
	}
	log.Println("----------")
}
