package main

import (
	"git.dragse.it/anthrove/e621-sdk-go/pkg/e621/endpoints"
	"git.dragse.it/anthrove/e621-sdk-go/pkg/e621/model"
	_ "github.com/joho/godotenv/autoload"
	"log"
	"net/http"
	"os"
)

func main() {
	// Define the request context with essential information.
	requestContext := model.RequestContext{
		Client:    http.Client{},
		Host:      "https://e621.net",
		UserAgent: "Go-e621-SDK (@username)",
		Username:  os.Getenv("API_USER"), // Replace with your username
		APIKey:    os.Getenv("API_KEY"),  // Replace with your API key
	}

	// Log: Getting a single note.
	log.Println("Getting single note: ")

	// Specify the note ID for retrieval.
	noteID := "36957" // Replace with the desired note's ID.

	// Call the GetNote function to retrieve the specified note.
	note, err := endpoints.GetNote(requestContext, noteID)

	if err != nil {
		log.Println(err)
	} else {
		// Log the body of the retrieved note.
		log.Println(note.Body)
	}
	log.Println("----------")

	// Log: Getting a list of notes.
	log.Println("Getting a list of notes: ")

	// Define query parameters for retrieving a list of notes.
	query := map[string]string{
		"limit": "5",
	}

	// Call the GetNotes function to retrieve a list of notes based on the query parameters.
	notes, err := endpoints.GetNotes(requestContext, query)

	if err != nil {
		log.Println(err)
	} else {
		// Log the number of notes retrieved.
		log.Println(len(notes))
	}
	log.Println("----------")
}
