package main

import (
	"git.dragse.it/anthrove/e621-sdk-go/pkg/e621/endpoints"
	"git.dragse.it/anthrove/e621-sdk-go/pkg/e621/model"
	_ "github.com/joho/godotenv/autoload"
	"log"
	"net/http"
	"os"
)

func main() {
	// Define the request context with essential information.
	requestContext := model.RequestContext{
		Client:    http.Client{},
		Host:      "https://e621.net",
		UserAgent: "Go-e621-SDK (@username)",
		Username:  os.Getenv("API_USER"), // Replace with your username
		APIKey:    os.Getenv("API_KEY"),  // Replace with your API key
	}

	// Log: Getting a single pool.
	log.Println("Getting single pool: ")

	// Specify the pool ID for retrieval.
	poolID := "36957" // Replace with the desired pool's ID.

	// Call the GetPool function to retrieve the specified pool.
	pool, err := endpoints.GetPool(requestContext, poolID)

	if err != nil {
		log.Println(err)
	} else {
		// Log the name of the retrieved pool.
		log.Println(pool.Name)
	}
	log.Println("----------")

	// Log: Getting a list of pools.
	log.Println("Getting a list of pools: ")

	// Define query parameters for retrieving a list of pools.
	query := map[string]string{
		"limit": "5",
	}

	// Call the GetPools function to retrieve a list of pools based on the query parameters.
	pools, err := endpoints.GetPools(requestContext, query)

	if err != nil {
		log.Println(err)
	} else {
		// Log the number of pools retrieved.
		log.Println(len(pools))
	}
	log.Println("----------")
}
