package main

import (
	"git.dragse.it/anthrove/e621-sdk-go/pkg/e621/builder"
	"git.dragse.it/anthrove/e621-sdk-go/pkg/e621/model"
	_ "github.com/joho/godotenv/autoload"
	"log"
	"net/http"
	"os"
)

func main() {
	// Define the request context with essential information.
	requestContext := model.RequestContext{
		Client:    http.Client{},
		Host:      "https://e621.net",
		UserAgent: "Go-e621-SDK (@username)",
		Username:  os.Getenv("API_USER"), // Replace with your username
		APIKey:    os.Getenv("API_KEY"),  // Replace with your API key
	}

	// Log: Getting favorites from the API.
	log.Println("Getting favorites API user: ")

	// Call the GetFavorites function to retrieve favorite posts.
	getFavorites := builder.NewGetFavoritesBuilder(requestContext)
	posts, err := getFavorites.SetLimit(5).Execute()

	if err != nil {
		log.Println(err)
	} else {
		// Log the URL of the first favorite post.
		log.Println(posts[0].File.URL)
	}
	log.Println("----------")

	// Log: Getting favorites for a specific user.
	log.Println("Getting favorites for user: ")

	// Call the GetFavorites function to retrieve favorite posts for the specified user.
	posts, err = getFavorites.SetLimit(5).SetUserID(1337).Execute()
	if err != nil {
		log.Println(err)
	} else {
		// Log the URL of the first favorite post.
		log.Println(posts[0].File.URL)
	}
	log.Println("----------")
}
