package builder

import (
	"git.dragse.it/anthrove/e621-sdk-go/pkg/e621/model"
	"git.dragse.it/anthrove/e621-sdk-go/pkg/e621/utils"
	"github.com/jarcoal/httpmock"
	"net/http"
	"testing"
)

func TestGetNote(t *testing.T) {
	httpmock.Activate()
	defer httpmock.DeactivateAndReset()

	response, err := utils.LoadJsonTestData[model.Note]("../../../tests/note.json")
	if err != nil {
		t.Error(err)
		return
	}

	responser, err := httpmock.NewJsonResponder(200, response)
	if err != nil {
		t.Error(err)
		return
	}
	httpmock.RegisterResponder("GET", "https://e621.net/notes/36957.json", responser)

	requestContext := model.RequestContext{
		Client:    http.Client{},
		Host:      "https://e621.net",
		UserAgent: "Go-e621-SDK (@username)",
		Username:  "memo",
		APIKey:    "123456",
	}

	getNote := NewGetNoteBuilder(requestContext)
	pool, err := getNote.SetNoteID(36957).Execute()
	if err != nil {
		t.Error(err)
		return
	}

	if pool.ID == response.ID && pool.Body == response.Body {
		return
	}

	t.Errorf("Respons did not match mock data:\nOriginal: %v\nMock:     %v", pool, response)

}
