package builder

import (
	"context"
	"git.dragse.it/anthrove/e621-sdk-go/pkg/e621/endpoints"
	"git.dragse.it/anthrove/e621-sdk-go/pkg/e621/model"
	"strconv"
)

// TagBuilder represents a builder for constructing queries to retrieve a specific tag.
type TagBuilder interface {
	// SetTagID sets the tag ID for the query.
	SetTagID(tagID int) TagBuilder
	// Execute sends the constructed query and returns the requested tag and an error, if any.
	Execute() (model.Tag, error)
}

// NewGetTagBuilder creates a new TagBuilder with the provided RequestContext.
func NewGetTagBuilder(requestContext model.RequestContext) TagBuilder {
	return &getTag{requestContext: requestContext}
}

type getTag struct {
	requestContext model.RequestContext
	tagID          int
}

// SetTagID sets the tag ID for the query.
func (g *getTag) SetTagID(tagID int) TagBuilder {
	g.tagID = tagID
	return g
}

// Execute sends the constructed query and returns the requested tag and an error, if any.
func (g *getTag) Execute() (model.Tag, error) {
	if g.requestContext.RateLimiter != nil {
		err := g.requestContext.RateLimiter.Wait(context.Background())
		if err != nil {
			return model.Tag{}, err
		}
	}
	tag, err := endpoints.GetTag(g.requestContext, strconv.Itoa(g.tagID))
	if err != nil {
		return model.Tag{}, err
	}
	return tag, nil
}
