package endpoints

import (
	"git.dragse.it/anthrove/e621-sdk-go/pkg/e621/model"
	"git.dragse.it/anthrove/e621-sdk-go/pkg/e621/utils"
	"github.com/jarcoal/httpmock"
	"net/http"
	"testing"
)

func TestGetTag(t *testing.T) {
	httpmock.Activate()
	defer httpmock.DeactivateAndReset()

	response, err := utils.LoadJsonTestData[model.Tag]("../../../tests/tag.json")
	if err != nil {
		t.Error(err)
		return
	}

	responder, err := httpmock.NewJsonResponder(200, response)
	if err != nil {
		t.Error(err)
		return
	}
	httpmock.RegisterResponder("GET", "https://e621.net/tags/165165.json", responder)

	requestContext := model.RequestContext{
		Client:    http.Client{},
		Host:      "https://e621.net",
		UserAgent: "Go-e621-SDK (@username)",
		Username:  "memo",
		APIKey:    "123456",
	}

	tag, err := GetTag(requestContext, "165165")
	if err != nil {
		t.Error(err)
		return
	}

	if tag.ID == response.ID && tag.Name == response.Name && tag.CreatedAt == response.CreatedAt {
		return
	}

	t.Errorf("Respons did not match mock data:\nOriginal: %v\nMock:     %v", tag, response)

}
