package model

type UserID int64
type UserLevel int
type Order string

const (
	Anonymus    UserLevel = 0
	Blocked     UserLevel = 10
	Member      UserLevel = 20
	Privilaged  UserLevel = 30
	FormerStaff UserLevel = 34
	Janitor     UserLevel = 35
	Moderator   UserLevel = 40
	Admin       UserLevel = 50
)

const (
	JoinDate        Order = "date"
	UserName        Order = "name"
	PostUploadCount Order = "post_upload_count"
	NoteCount       Order = "note_count"
	PostUpdateCount Order = "post_upload_count"
)

type User struct {
	WikiPageVersionCount  int64     `json:"wiki_page_version_count"`
	ArtistVersionCount    int64     `json:"artist_version_count"`
	PoolVersionCount      int64     `json:"pool_version_count"`
	ForumPostCount        int64     `json:"forum_post_count"`
	CommentCount          int64     `json:"comment_count"`
	FlagCount             int64     `json:"flag_count"`
	FavoriteCount         int64     `json:"favorite_count"`
	PositiveFeedbackCount int64     `json:"positive_feedback_count"`
	NeutralFeedbackCount  int64     `json:"neutral_feedback_count"`
	NegativeFeedbackCount int64     `json:"negative_feedback_count"`
	UploadLimit           int64     `json:"upload_limit"`
	ID                    UserID    `json:"id"`
	CreatedAt             string    `json:"created_at"`
	Name                  string    `json:"name"`
	Level                 UserLevel `json:"level"`
	BaseUploadLimit       int64     `json:"base_upload_limit"`
	PostUploadCount       int64     `json:"post_upload_count"`
	PostUpdateCount       int64     `json:"post_update_count"`
	NoteUpdateCount       int64     `json:"note_update_count"`
	IsBanned              bool      `json:"is_banned"`
	CanApprovePosts       bool      `json:"can_approve_posts"`
	CanUploadFree         bool      `json:"can_upload_free"`
	LevelString           string    `json:"level_string"`
	AvatarID              PostID    `json:"avatar_id"`
}
